@@ -88,7 +88,8 @@ class InstancesTest(testtools.TestCase):
         super(InstancesTest, self).tearDown()
         instances.Instances.__init__ = self.orig__init
 
-    def test_create(self):
+    @mock.patch('warnings.warn')
+    def test_create(self, mock_warn):
         def side_effect_func(path, body, inst):
             return path, body, inst
 
@@ -98,7 +99,7 @@ class InstancesTest(testtools.TestCase):
                                         ['db1', 'db2'], ['u1', 'u2'],
                                         datastore="datastore",
                                         datastore_version="datastore-version",
-                                        nics=nics)
+                                        nics=nics, slave_of='test')
         self.assertEqual("/instances", p)
         self.assertEqual("instance", i)
         self.assertEqual(['db1', 'db2'], b["instance"]["databases"])
@@ -110,6 +111,11 @@ class InstancesTest(testtools.TestCase):
                          b["instance"]["datastore"]["version"])
         self.assertEqual(nics, b["instance"]["nics"])
         self.assertEqual(103, b["instance"]["flavorRef"])
+        # Assert that slave_of is not used and if specified, there is a warning
+        # and it's value is used for replica_of.
+        self.assertEqual('test', b['instance']['replica_of'])
+        self.assertNotIn('slave_of', b['instance'])
+        self.assertTrue(mock_warn.called)
 
     def test_list(self):
         page_mock = mock.Mock()
@@ -211,8 +217,14 @@ class InstancesTest(testtools.TestCase):
     def test_edit(self):
         resp = mock.Mock()
         resp.status_code = 204
-        body = None
-        self.instances.api.client.patch = mock.Mock(return_value=(resp, body))
+
+        def fake_patch(url, body):
+            # Make sure we never pass slave_of to the API.
+            self.assertIn('instance', body)
+            self.assertNotIn('slave_of', body['instance'])
+            return resp, None
+
+        self.instances.api.client.patch = mock.Mock(side_effect=fake_patch)
         self.instances.edit(123)
         self.instances.edit(123, 321)
         self.instances.edit(123, 321, 'name-1234')
